==> haskell-uuid-types-1.0.3-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-uuid-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid-types
version: 1.0.3
id: uuid-types-1.0.3-7rLLlA2cSVfK1KHX6HTIFi
key: uuid-types-1.0.3-7rLLlA2cSVfK1KHX6HTIFi
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: aslatter@gmail.com
homepage: https://github.com/aslatter/uuid
synopsis: Type definitions for Universally Unique Identifiers
description:
    This library contains type definitions for Universally Unique Identifiers
    and basic conversion functions.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.UUID.Types Data.UUID.Types.Internal.Builder
    Data.UUID.Types.Internal
abi: 105022e2f813d9b09db2a5ee55daa55f
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/uuid-types-1.0.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/uuid-types-1.0.3
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/uuid-types-1.0.3
hs-libraries: HSuuid-types-1.0.3-7rLLlA2cSVfK1KHX6HTIFi
depends:
    base-4.9.1.0 binary-0.8.3.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    hashable-1.2.6.0-3tyIJq2bWc6AwvrDmNvwy7
    random-1.1-9tceXaeYIMZ4JrKq20Egog
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-uuid-types/html/uuid-types.haddock
haddock-html: /usr/share/doc/haskell-uuid-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-types-1.0.3-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-uuid-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid-types
version: 1.0.3
id: uuid-types-1.0.3-I7xNINqiSgy8XiSgWjW585
key: uuid-types-1.0.3-I7xNINqiSgy8XiSgWjW585
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: aslatter@gmail.com
homepage: https://github.com/aslatter/uuid
synopsis: Type definitions for Universally Unique Identifiers
description:
    This library contains type definitions for Universally Unique Identifiers
    and basic conversion functions.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.UUID.Types Data.UUID.Types.Internal.Builder
    Data.UUID.Types.Internal
abi: c1b32757ceec303837b87452eaffdc51
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/uuid-types-1.0.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/uuid-types-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/uuid-types-1.0.3
hs-libraries: HSuuid-types-1.0.3-I7xNINqiSgy8XiSgWjW585
depends:
    base-4.9.1.0 binary-0.8.3.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    random-1.1-9tceXaeYIMZ4JrKq20Egog
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-uuid-types/html/uuid-types.haddock
haddock-html: /usr/share/doc/haskell-uuid-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
